@@ -20,6 +20,7 @@ from ..utils import (
     resolve_executor_indices,
     timed_step_status,
     wait_ready_no_timeout,
+    ensure_config
 )
 from .ssh import get_ssh_method_and_pod, ssh_to_pod
 
@@ -105,14 +106,17 @@ def _auto_select_executor(
 ) -> Optional[ExecutorInfo]:
     """Automatically select best executor based on filters."""
     from .ls import ls_store_executor
-    
+
     with loading_status("Finding best executor", ""):
         executors = lium.ls(gpu_type=gpu)
         executors = _apply_executor_filters(executors, gpu_count=count, country_code=country)
         
         if not executors:
-            filter_desc = _build_filter_description(gpu, count, country)
-            console.error(f"All matching GPUs are currently rented out. (filters: {filter_desc})")
+            if gpu not in lium.gpu_types():
+                console.error(f"GPU '{gpu}' Not recognized")
+            else:
+                filter_desc = _build_filter_description(gpu, count, country)
+                console.error(f"All matching GPUs are currently rented out. (filters: {filter_desc})")
             console.info(f"Tip: {console.get_styled('lium ls', 'success')}")
             return None
         
@@ -306,6 +310,7 @@ def up_command(
       lium up --country US          # Filter by country code
       lium up --gpu H200 --country FR  # Combine multiple filters
     """
+    ensure_config()
     lium = Lium()
     
     # Resolve executor
